<?php

namespace Realestate\Seo\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Realestate\Seo\Models\Seo;

class SeoPolicy
{

    /**
     * Determine if the given user can view the seo.
     *
     * @param UserPolicyInterface $authUser
     * @param Seo $seo
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Seo $seo)
    {
        if ($authUser->canDo('seo.seo.view') && $authUser->isAdmin()) {
            return true;
        }

        return $seo->user_id == user_id() && $seo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a seo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('seo.seo.create');
    }

    /**
     * Determine if the given user can update the given seo.
     *
     * @param UserPolicyInterface $authUser
     * @param Seo $seo
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Seo $seo)
    {
        if ($authUser->canDo('seo.seo.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $seo->user_id == user_id() && $seo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given seo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Seo $seo)
    {
        return $seo->user_id == user_id() && $seo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given seo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Seo $seo)
    {
        if ($authUser->canDo('seo.seo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given seo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Seo $seo)
    {
        if ($authUser->canDo('seo.seo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
